import * as react_jsx_runtime from 'react/jsx-runtime';
import * as react from 'react';
import { Dispatch, SetStateAction, ReactNode } from 'react';
import { EVMSmartWallet, SolanaSmartWallet } from '@crossmint/wallets-sdk';
import { GetOrCreateWalletProps } from '../types/wallet.js';

type ValidWalletState = {
    status: "not-loaded" | "in-progress";
} | {
    status: "loaded";
    wallet: EVMSmartWallet;
    type: "evm-smart-wallet";
} | {
    status: "loaded";
    wallet: SolanaSmartWallet;
    type: "solana-smart-wallet";
} | {
    status: "loading-error";
    error: string;
};
type WalletContextFunctions = {
    getOrCreateWallet: (args: GetOrCreateWalletProps) => Promise<{
        startedCreation: boolean;
        reason?: string;
    }>;
    setState: Dispatch<SetStateAction<ValidWalletState>>;
    clearWallet: () => void;
};
type WalletType = {
    "evm-smart-wallet": EVMSmartWallet;
    "solana-smart-wallet": SolanaSmartWallet;
};
type LoadedWalletState<T extends keyof WalletType> = {
    status: "loaded";
    wallet: WalletType[T];
    type: T;
    error?: undefined;
};
type WalletContext = ({
    status: "not-loaded" | "in-progress";
    wallet?: undefined;
    type?: undefined;
    error?: undefined;
} & WalletContextFunctions) | ({
    status: "loading-error";
    wallet?: undefined;
    type?: undefined;
    error: string;
} & WalletContextFunctions) | (LoadedWalletState<"evm-smart-wallet"> & WalletContextFunctions) | (LoadedWalletState<"solana-smart-wallet"> & WalletContextFunctions);
declare const WalletContext: react.Context<WalletContext>;
declare function deriveErrorState(error: unknown): {
    status: "loading-error";
    error: string;
};
declare function CrossmintWalletProvider({ children, }: {
    children: ReactNode;
}): react_jsx_runtime.JSX.Element;

export { CrossmintWalletProvider, type ValidWalletState, WalletContext, deriveErrorState };
